use strict;
use warnings;
use Test::More tests => 21;
use File::Temp qw(mkstemp);

use_ok('LATMOS::Accounts::Utils');
use_ok('LATMOS::Accounts::Mail');
use LATMOS::Accounts::Log;

ok(la_log(LA_NOTICE, "a notice"), "can run la_log");

my ($fh, $file) = mkstemp( "tmpfileXXXXX" );
print $fh <<EOF;
attr1: attr1
attr: val1
attr: val2
EOF

seek($fh, 0, 0);

my %attributes = LATMOS::Accounts::Utils::parse_obj_file($fh);
$fh = undef;
unlink($file);

# now testing
is($attributes{'attr1'}, 'attr1', "can get attribute from file");
ok(eq_set($attributes{'attr'}, [ qw(val1 val2) ]),
        "can get multiple values attribute");

$ENV{EDITOR} = 'sleep 1; /bin/touch';

ok(LATMOS::Accounts::Utils::dump_read_temp_file(
        sub { 1; }, sub { 1; }), "Can edit temp file");

ok(!LATMOS::Accounts::Utils::check_oid_validity('toto'), '"toto" is valid oid');
ok(!LATMOS::Accounts::Utils::check_oid_validity('toTo'), '"toTo" is valid oid');
ok(LATMOS::Accounts::Utils::check_oid_validity('to to'), '"to to" is invalid oid');
ok(LATMOS::Accounts::Utils::check_oid_validity(' toto'), '" toto" is invalid oid');

ok(!LATMOS::Accounts::Utils::check_ug_validity('toto'), '"toto" is valid username');
ok(LATMOS::Accounts::Utils::check_ug_validity('toTo'), '"toTo" is invalid username');
ok(LATMOS::Accounts::Utils::check_ug_validity('to to'), '"to to" is invalid username');
ok(LATMOS::Accounts::Utils::check_ug_validity(' toto'), '" toto" is invalid username');
ok(LATMOS::Accounts::Utils::check_ug_validity('5toto'), '"5toto" is invalid username');
ok(!LATMOS::Accounts::Utils::check_ug_validity('t5oto'), '"t5oto" is valid username');

is(yesno('yes'),  1, 'yes is true');
is(yesno('true'), 1, 'true is true');
is(yesno('23'),   1, '23 is true');
is(yesno('no'),   0, 'no is false');
is(yesno('what'), 'what', 'what is what?');
